import 'package:flutter/material.dart';
import '../marker_data.dart';
import '../consts.dart';
import 'package:flutter_map/flutter_map.dart';
import 'package:latlong2/latlong.dart';
import 'package:fl_chart/fl_chart.dart';
import 'quick_view_chart.dart';
import 'stat_charts.dart';

class MapContainerWidget extends StatefulWidget {
  final List<MarkerTemplate> markerList;

  const MapContainerWidget({Key? key, required this.markerList}) : super(key: key);

  @override
  _MapContainerWidgetState createState() => _MapContainerWidgetState();
}

class _MapContainerWidgetState extends State<MapContainerWidget> {

  MarkerTemplate? selectedMarker;
  bool isMinimized = true; // Quick view box state tacker

  @override
  Widget build(BuildContext context) {

    const double contPadding = 30; // Container padding space

    return LayoutBuilder(
      builder: (context, constraints) {
        double screenWidth = constraints.maxWidth;
        double boxWidth = 0.86;
        double boxHeight = 1.4;

        return Column(
          children: [
            const SizedBox(height: contPadding),
            ClipRRect(
              borderRadius: BorderRadius.circular(20),
              child: Container(
                width: screenWidth * boxWidth,
                height: screenWidth * boxHeight,
                child: FlutterMap(
                  options: MapOptions(
                    center: LatLng(60.7666, 10.8471),
                    zoom: 9.0,
                  ),
                  children: [
                    TileLayer(
                      urlTemplate: "https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png",
                      subdomains: const ['a', 'b', 'c'],
                    ),
                    MarkerLayer(
                      markers: widget.markerList.map((MarkerTemplate markerTemplate) {
                        return Marker(
                          width: markerTemplate.size,
                          height: markerTemplate.size,
                          point: markerTemplate.location,
                          builder: (ctx) => GestureDetector(
                            onTap: () {
                              setState(() {
                                selectedMarker = markerTemplate;
                              });
                            },
                            child: Image.asset(
                              'assets/icons/circle-red.png',
                              color: markerTemplate.color,
                              width: markerTemplate.size,
                              height: markerTemplate.size,
                            ),
                          ),
                        );
                      }).toList(),
                    ),
                    Positioned(
                      bottom: 10,
                      right: 10,
                      child: ClipRRect(
                        borderRadius: BorderRadius.circular(10),
                        child: Container(
                          width: (screenWidth * boxWidth) / 2.4,
                          height: isMinimized ? 20 : (screenWidth * boxWidth) / 2.4,
                          color: Colors.blue.withOpacity(0.7),
                          child: Stack(
                            children: [
                              Visibility( // Content only visible when box is maximized
                                visible: !isMinimized && selectedMarker != null,
                                child: Center(
                                  child: Padding(
                                    padding: const EdgeInsets.only(right: 16.0, top: 17.0),
                                    child: SizedBox(
                                      width: (screenWidth * boxWidth) / 2.3,
                                      height: (screenWidth * boxWidth) / 2.3,
                                      child: const QuickViewChart(),
                                    ),
                                  ),
                                ),
                              ),
                              Positioned(
                                top: 0,
                                right: 5,
                                child: GestureDetector(
                                  onTap: () {
                                    setState(() {
                                      isMinimized = !isMinimized; // Toggle the minimized state
                                    });
                                  },
                                  child: Icon(isMinimized ? Icons.arrow_drop_up : Icons.arrow_drop_down),
                                ),
                              ),
                            ],
                          ),
                        ),
                      ),
                    ),
                  ],
                ),
              ),
            ),
            const SizedBox(height: contPadding), // Padding between containers
            ClipRRect(
              borderRadius: BorderRadius.circular(20),
              child: Container(
                width: screenWidth * boxWidth,
                height: screenWidth * boxHeight * 1.5, // NB: make dynamic
                child: Align(
                  alignment: Alignment.topLeft,
                  child: Padding(
                    padding: const EdgeInsets.only(top: 20, left: 20), // Edge padding, text
                    child: Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                         Text(
                          'Ice stats',
                          style: titleStyle,
                        ),
                        Text(
                          'Safety level: ${selectedMarker?.geoData.safetyLevel}',
                          style: regTextStyle,
                        ),
                        Text(
                          'Location: (${selectedMarker?.geoData.latitude},${selectedMarker?.geoData.longitude})',
                          style: regTextStyle,
                        ),
                        const SizedBox(height: contPadding),
                        const StatCharts(),
                      ],
                    ),
                  ),
                ),
              ),
            ),
          ],
        );
      },
    );
  }
}